summaryrefslogtreecommitdiffhomepage
path: root/Private/KernelKit/CodeManager.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'Private/KernelKit/CodeManager.hpp')
-rw-r--r--Private/KernelKit/CodeManager.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/Private/KernelKit/CodeManager.hpp b/Private/KernelKit/CodeManager.hpp
index ed42517a..5b06e4a4 100644
--- a/Private/KernelKit/CodeManager.hpp
+++ b/Private/KernelKit/CodeManager.hpp
@@ -20,7 +20,7 @@
#define kUPPNameLen 64
-namespace HCore {
+namespace NewOS {
/// \brief Much like Mac OS's UPP.
/// This is read-only by design.
/// It handles different kind of code.
@@ -30,4 +30,4 @@ typedef struct UniversalProcedureTable final {
const VoidPtr TRAP;
const SizeT ARCH;
} PACKED UniversalProcedureTableType;
-} // namespace HCore \ No newline at end of file
+} // namespace NewOS \ No newline at end of file